/* $Id: gethost.c,v 1.1 2000/05/17 04:52:06 chad Exp $*/

/*
 * Print the "hostent" information for every host whose name is
 * specified on the command line.
 */

#include	<stdio.h>
#include	<sys/types.h>
#include	<netdb.h>		/* for struct hostent */
#include	<sys/socket.h>		/* for AF_INET */
#include	<netinet/in.h>		/* for struct in_addr */
#include	<arpa/inet.h>		/* for inet_ntoa() */

#define FALSE 0
#define TRUE ~FALSE

main(argc, argv)
int	argc;
char	**argv;
{
	register char		*ptr;
	register struct hostent	*hostptr;
	int			tcp_flag = FALSE;	/* stream or dgram ? */

	if (argc < 2) {
	    printf("Usage: %s hostname [...]\n", argv[0]);
	    exit(1);
	}

	if (argc > 2) {	/* use virtual circuit if more than one query */
	    tcp_flag = TRUE;
	    sethostent(TRUE);
	}

	while (--argc > 0) {
		ptr = *++argv;
		if ( (hostptr = gethostbyname(ptr)) == NULL) {
		    printf("gethostbyname error for host %s: ", ptr);
		    err_ret(h_errno);
			continue;
		}
		printf("\nOfficial host name: %s\n", hostptr->h_name);

		/* go through the list of aliases */
		while ( (ptr = *(hostptr->h_aliases)) != NULL) {
			printf("	alias: %s\n", ptr);
			hostptr->h_aliases++;
		}

		switch (hostptr->h_addrtype) {
		case AF_INET:
			pr_inet(hostptr->h_addr_list, hostptr->h_length);
			break;

		default:
			printf("unknown address type");
			break;
		}
	}
	if (tcp_flag)
	    endhostent();
}

/*
 * Go through a list of Internet addresses,
 * printing each one in dotted-decimal notation.
 */

pr_inet(listptr, length)
char	**listptr;
int	length;
{
	struct in_addr	*ptr;

	while ( (ptr = (struct in_addr *) *listptr++) != NULL)
		printf("	Internet address: %s\n", inet_ntoa(*ptr));
}

/*
 * Display hostent error code
 */

err_ret(err)
int	err;
{
    switch (err) {
	case HOST_NOT_FOUND:
	    printf("Authoritative Answer Host not found\n");
	    break;
	case TRY_AGAIN:
	    printf("Non-Authoritive Host not found, or server fail\n");
	    break;
	case NO_RECOVERY:
	    printf("Non recoverable errors, FORMERR, REFUSED, NOTIMP\n");
	    break;
	case NO_DATA:
	    printf("Valid name, no data record of requested type\n");
	default:
	    printf("Unknown error code %d\n", err);
	    break;
    }
}
